Crate rings_codec

Crate rings_codec 

Serde wire helpers backed by the Rings postcard codec.

Enums

Error
Codec error returned by Rings wire helper functions.

Functions

deserialize
Deserialize a serde value using the Rings wire encoding.
deserialize_enum_variant
Read an enum variant index without deserializing its body.
deserialize_prefix
Deserialize one value from the start of bytes and return the unconsumed suffix.
serialize
Serialize a serde value using the Rings wire encoding.
serialized_size
Return the serialized size of a serde value using the default wire encoding.

Type Aliases

Result
Codec result type.